@@ -1,5 +1,5 @@
 /*
-    C++ Matrix/Vector templates (GNU Gama / matvec 1.0.01)
+    C++ Matrix/Vector templates (GNU Gama / matvec)
     Copyright (C) 1999, 2007, 2009  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ Matrix/Vector template library.
@@ -59,7 +59,6 @@ Mat<Float, Exc> pinv(const Mat<Float, Exc>& A)
   const Mat<Float, Exc>& V = svd.SVD_V();
 
   Vec<Float,Exc> W_inv(N);
-  Float t = svd.tol();
   for (Index k=1; k<=N; k++)
     if (!svd.lindep(k))
       W_inv(k) = 1 / W(k);
